@@ -62,19 +62,6 @@ CHANNEL_RE = re.compile(CHANNEL_REGEXP)
 GPS_MIN = 946339215
 
 
-TD_UNIT_MAP = [
-    ('years', 31536000, '{td.years}y'),
-    ('weeks', 7*86400, '{td.weeks}w'),
-    ('days', 86400, '{td.days}d'),
-    ('hours', 3600, '{td.hours}h'),
-    ('minutes', 60, '{td.minutes}m'),
-    ('seconds', 1, '{td.seconds}s'),
-    ('msecs', 0.001, '{td.msecs}ms'),
-    ('usecs', 0.000001, '{td.usecs}μs'),
-    ('nsecs', 0.000000001, '{td.nsecs}ns'),
-]
-
-
 # tuples of major tick spacing and minor tick division
 TICK_SPACINGS = [
     (31536000, 4),
@@ -143,5 +130,9 @@ TICK_SPACINGS = [
 ]
 
 
+# date/time format string to time axis labels
+TICK_DATE_FMT = '%b %d %Y\n%H:%M:%S %Z'
+
+
 # fill color for labels
 LABEL_FILL = (0, 0, 0, 200)
