@@ -185,6 +185,14 @@ class NDScope(QMainWindow, Ui_MainWindow):
         self.trendSecMinThresh.setText(str(const.TREND_TRANS_THRESHOLD['sec/min']))
         self.trendSecMinThresh.returnPressed.connect(self._set_trend_secmin)
 
+        ##########
+        # axis
+
+        self.timeAxisRelativeSelect.toggled.connect(lambda: self.time_axis_select('relative'))
+        self.timeAxisGPSSelect.toggled.connect(lambda: self.time_axis_select('gps'))
+        self.timeAxisUTCSelect.toggled.connect(lambda: self.time_axis_select('utc'))
+        self.timeAxisLocalSelect.toggled.connect(lambda: self.time_axis_select('local'))
+
         ##########
         # trigger
 
@@ -558,7 +566,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         start, end = self.get_range()
         return abs(end - start)
 
-    def preferred_trend(self, online=False):
+    def preferred_trend(self):
         """preferred trend for the current time span"""
         trend = TREND_OPTIONS[self.trendSelectGroup.checkedId()]
         if trend == 'auto':
@@ -579,17 +587,17 @@ class NDScope(QMainWindow, Ui_MainWindow):
         """Start online mode
 
         """
-        trend = self.preferred_trend(online=True)
-        if trend == 'min':
-            self.status_error("Online minute trends not supported.  Try a smaller window.")
-            return
-        logger.info('START')
         if window:
             span = abs(min(window))
         else:
             span = self.get_span()
             window = (-span, 0)
         self.set_window(*window)
+        trend = self.preferred_trend()
+        if trend == 'min':
+            self.status_error("Online minute trends not supported.  Try a smaller window.")
+            return
+        logger.info('START')
         self.data.online_start(trend, span)
 
     def stop(self):
@@ -705,6 +713,8 @@ class NDScope(QMainWindow, Ui_MainWindow):
         self.startButton2.setEnabled(False)
         self.stopButton.setEnabled(True)
         self.stopButton2.setEnabled(True)
+        self.timeAxisRelativeSelect.setChecked(True)
+        self.axisTab.setEnabled(False)
 
     # SLOT
     def _data_retrieve_start(self, msg):
@@ -753,6 +763,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         self.startButton2.setEnabled(True)
         self.stopButton.setEnabled(False)
         self.stopButton2.setEnabled(False)
+        self.axisTab.setEnabled(True)
         if self._data_done_status(signal):
             return
         self._data_done_reset()
@@ -946,6 +957,18 @@ class NDScope(QMainWindow, Ui_MainWindow):
     def _set_trend_secmin(self, *args):
         const.TREND_TRANS_THRESHOLD['sec/min'] = int(self.trendSecMinThresh.text())
 
+    ##########
+    # AXIS
+
+    def time_axis_select(self, mode):
+        logger.debug(f"time axis select: {mode}")
+        for plot in self.plots:
+            plot.axes['bottom']['item'].setTickStringsMode(mode)
+        if mode == 'relative':
+            self.referenceTimeLabel.show()
+        else:
+            self.referenceTimeLabel.hide()
+
     ##########
     # TRIGGER
 
@@ -1167,7 +1190,6 @@ class NDScope(QMainWindow, Ui_MainWindow):
         else:
             self.disable_y_cursors()
 
-
     ##########
     # STYLE
 
